+++
title = "Replace only \"linkTitle\" key"
linktitle = "Replace only \"linkTitle\" key"
tags = ["front-matter", "keys", "replace", "linktitle"]
draft = false
+++

This post will have the `linkTitle` key in front-matter replaced with
`linktitle`.
